package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.oiw.ElGamalParameter;
import cn.com.infosec.asn1.oiw.OIWObjectIdentifiers;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.SubjectPublicKeyInfo;
import cn.com.infosec.crypto.params.ElGamalPublicKeyParameters;
import cn.com.infosec.jce.interfaces.ElGamalPublicKey;
import cn.com.infosec.jce.spec.ElGamalParameterSpec;
import cn.com.infosec.jce.spec.ElGamalPublicKeySpec;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.math.BigInteger;
import javax.crypto.interfaces.DHPublicKey;
import javax.crypto.spec.DHParameterSpec;
import javax.crypto.spec.DHPublicKeySpec;

public class JCEElGamalPublicKey implements ElGamalPublicKey, DHPublicKey {
   static final long serialVersionUID = 8712728417091216948L;
   private BigInteger y;
   private ElGamalParameterSpec elSpec;

   JCEElGamalPublicKey(ElGamalPublicKeySpec spec) {
      this.y = spec.getY();
      this.elSpec = new ElGamalParameterSpec(spec.getParams().getP(), spec.getParams().getG());
   }

   JCEElGamalPublicKey(DHPublicKeySpec spec) {
      JCEElGamalPublicKey var10000 = this;
      super();
      this.y = spec.getY();
      BigInteger var2 = spec.getP();
      var10000.elSpec = new ElGamalParameterSpec(var2, spec.getG());
   }

   JCEElGamalPublicKey(ElGamalPublicKey key) {
      this.y = key.getY();
      this.elSpec = key.getParameters();
   }

   JCEElGamalPublicKey(DHPublicKey key) {
      this.y = key.getY();
      this.elSpec = new ElGamalParameterSpec(key.getParams().getP(), key.getParams().getG());
   }

   JCEElGamalPublicKey(ElGamalPublicKeyParameters params) {
      this.y = params.getY();
      this.elSpec = new ElGamalParameterSpec(params.getParameters().getP(), params.getParameters().getG());
   }

   JCEElGamalPublicKey(BigInteger y, ElGamalParameterSpec elSpec) {
      this.y = y;
      this.elSpec = elSpec;
   }

   JCEElGamalPublicKey(SubjectPublicKeyInfo info) {
      JCEElGamalPublicKey var10000 = this;
      JCEElGamalPublicKey var10001 = this;
      SubjectPublicKeyInfo var10002 = info;
      super();
      ElGamalParameter var3;
      var3 = new ElGamalParameter.<init>((ASN1Sequence)info.getAlgorithmId().getParameters());

      DERInteger var5;
      try {
         var5 = (DERInteger)var10002.getPublicKey();
      } catch (IOException var2) {
         throw new IllegalArgumentException("invalid info structure in DSA public key");
      }

      var10001.y = var5.getValue();
      ElGamalParameter var10003 = var3;
      BigInteger var4 = var3.getP();
      var10000.elSpec = new ElGamalParameterSpec(var4, var10003.getG());
   }

   private void readObject(ObjectInputStream in) {
      this.y = (BigInteger)in.readObject();
      this.elSpec = new ElGamalParameterSpec((BigInteger)in.readObject(), (BigInteger)in.readObject());
   }

   private void writeObject(ObjectOutputStream out) {
      out.writeObject(this.getY());
      out.writeObject(this.elSpec.getP());
      out.writeObject(this.elSpec.getG());
   }

   public String getAlgorithm() {
      return "ElGamal";
   }

   public String getFormat() {
      return "X.509";
   }

   public byte[] getEncoded() {
      return (new SubjectPublicKeyInfo(new AlgorithmIdentifier(OIWObjectIdentifiers.elGamalAlgorithm, (new ElGamalParameter(this.elSpec.getP(), this.elSpec.getG())).getDERObject()), new DERInteger(this.y))).getDEREncoded();
   }

   public ElGamalParameterSpec getParameters() {
      return this.elSpec;
   }

   public DHParameterSpec getParams() {
      return new DHParameterSpec(this.elSpec.getP(), this.elSpec.getG());
   }

   public BigInteger getY() {
      return this.y;
   }
}
